@@ -32,10 +32,10 @@ for generating an anonymous JSON structure representing the graph.
 
 use 5.006;
 use strict;
-use JSON  ();
-use Graph ();
+use JSON  2.16 ();
+use Graph 0.85 ();
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 =pod
 
@@ -140,7 +140,7 @@ Adam Kennedy E<lt>adamk@cpan.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright 2009 Adam Kennedy.
+Copyright 2009 - 2012 Adam Kennedy.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
